@@ -1,6 +1,6 @@
 package Dist::Zilla::MVP::Reader::Finder;
 # ABSTRACT: the reader for dist.ini files
-$Dist::Zilla::MVP::Reader::Finder::VERSION = '5.047';
+$Dist::Zilla::MVP::Reader::Finder::VERSION = '5.048';
 use Moose;
 use Config::MVP::Reader 2.101540; # if_none
 extends 'Config::MVP::Reader::Finder';
@@ -28,15 +28,15 @@ Dist::Zilla::MVP::Reader::Finder - the reader for dist.ini files
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
