@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::CPANFile;
 # ABSTRACT: produce a cpanfile prereqs file
-$Dist::Zilla::Plugin::CPANFile::VERSION = '5.047';
+$Dist::Zilla::Plugin::CPANFile::VERSION = '5.048';
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -88,7 +88,7 @@ Dist::Zilla::Plugin::CPANFile - produce a cpanfile prereqs file
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 DESCRIPTION
 
@@ -103,11 +103,11 @@ file.  It defaults, of course, to F<cpanfile>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
