@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaNoIndex;
 # ABSTRACT: Stop CPAN from indexing stuff
-$Dist::Zilla::Plugin::MetaNoIndex::VERSION = '5.047';
+$Dist::Zilla::Plugin::MetaNoIndex::VERSION = '5.048';
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -131,7 +131,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 SYNOPSIS
 
@@ -199,11 +199,11 @@ Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
