@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Prereq;
 # ABSTRACT: (DEPRECATED) the old name of the Prereqs plugin
-$Dist::Zilla::Plugin::Prereq::VERSION = '5.047';
+$Dist::Zilla::Plugin::Prereq::VERSION = '5.048';
 use Moose;
 extends 'Dist::Zilla::Plugin::Prereqs';
 
@@ -39,7 +39,7 @@ Dist::Zilla::Plugin::Prereq - (DEPRECATED) the old name of the Prereqs plugin
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 SYNOPSIS
 
@@ -52,11 +52,11 @@ Dist::Zilla plugins: L<Prereqs|Dist::Zilla::Plugin::Prereqs>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
