@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::TestRelease;
 # ABSTRACT: extract archive and run tests before releasing the dist
-$Dist::Zilla::Plugin::TestRelease::VERSION = '5.047';
+$Dist::Zilla::Plugin::TestRelease::VERSION = '5.048';
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 
@@ -73,7 +73,7 @@ Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasin
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 DESCRIPTION
 
@@ -92,11 +92,11 @@ This plugin was originally contributed by Christopher J. Madsen.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
