@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::FakeClassic;
 # ABSTRACT: build something more or less like a "classic" CPAN dist
-$Dist::Zilla::PluginBundle::FakeClassic::VERSION = '5.047';
+$Dist::Zilla::PluginBundle::FakeClassic::VERSION = '5.048';
 use Moose;
 extends 'Dist::Zilla::PluginBundle::Classic';
 
@@ -40,15 +40,15 @@ Dist::Zilla::PluginBundle::FakeClassic - build something more or less like a "cl
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
