@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::ModuleMaker;
 # ABSTRACT: something that injects module files into the dist
-$Dist::Zilla::Role::ModuleMaker::VERSION = '5.047';
+$Dist::Zilla::Role::ModuleMaker::VERSION = '5.048';
 use Moose::Role;
 with qw(
   Dist::Zilla::Role::Plugin
@@ -39,7 +39,7 @@ Dist::Zilla::Role::ModuleMaker - something that injects module files into the di
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 DESCRIPTION
 
@@ -55,11 +55,11 @@ file for the module being created.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
