@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::PrereqScanner;
 # ABSTRACT: automatically extract prereqs from your modules
-$Dist::Zilla::Role::PrereqScanner::VERSION = '5.047';
+$Dist::Zilla::Role::PrereqScanner::VERSION = '5.048';
 use Moose::Role;
 with(
   'Dist::Zilla::Role::FileFinderUser' => {
@@ -186,7 +186,7 @@ Dist::Zilla::Role::PrereqScanner - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 5.047
+version 5.048
 
 =head1 ATTRIBUTES
 
@@ -230,11 +230,11 @@ The role was provided by Olivier Mengué (DOLMEN) and Philippe Bruhat (BOOK) at
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -249,7 +249,7 @@ __END__
 #pod
 #pod =head1 CREDITS
 #pod
-#pod The role was provided by Olivier MenguÃ© (DOLMEN) and Philippe Bruhat (BOOK) at Perl QA Hackathon 2016
+#pod The role was provided by Olivier Mengué (DOLMEN) and Philippe Bruhat (BOOK) at Perl QA Hackathon 2016
 #pod (but it is just a refactor of the AutoPrereqs plugin).
 #pod
 #pod =cut
